WARNING - OLD ARCHIVES

This is an archived copy of the Xen.org mailing list, which we have preserved to ensure that existing links to archives are not broken. The live archive, which contains the latest emails, can be found at http://lists.xen.org/
   
 
 
Xen 
 
Home Products Support Community News
 
   
 

xen-changelog

[Xen-changelog] [linux-2.6.18-xen] netfront accel: rename check_busy acc

To: xen-changelog@xxxxxxxxxxxxxxxxxxx
Subject: [Xen-changelog] [linux-2.6.18-xen] netfront accel: rename check_busy acceleration callback to check_ready
From: "Xen patchbot-linux-2.6.18-xen" <patchbot-linux-2.6.18-xen@xxxxxxxxxxxxxxxxxxx>
Date: Wed, 31 Oct 2007 15:00:50 -0700
Delivery-date: Wed, 31 Oct 2007 15:02:42 -0700
Envelope-to: www-data@xxxxxxxxxxxxxxxxxx
List-help: <mailto:xen-changelog-request@lists.xensource.com?subject=help>
List-id: BK change log <xen-changelog.lists.xensource.com>
List-post: <mailto:xen-changelog@lists.xensource.com>
List-subscribe: <http://lists.xensource.com/cgi-bin/mailman/listinfo/xen-changelog>, <mailto:xen-changelog-request@lists.xensource.com?subject=subscribe>
List-unsubscribe: <http://lists.xensource.com/cgi-bin/mailman/listinfo/xen-changelog>, <mailto:xen-changelog-request@lists.xensource.com?subject=unsubscribe>
Reply-to: xen-devel@xxxxxxxxxxxxxxxxxxx
Sender: xen-changelog-bounces@xxxxxxxxxxxxxxxxxxx
# HG changeset patch
# User Keir Fraser <keir@xxxxxxxxxxxxx>
# Date 1193765629 0
# Node ID d85cb3fd1011b1e3e086efc4e682a2b0e1732481
# Parent  7ab0c1e671a2f201280beb715b97827c80086592
netfront accel: rename check_busy acceleration callback to check_ready
Signed-off-by <kmansley@xxxxxxxxxxxxxx>
---
 drivers/xen/netfront/accel.c    |    8 ++++----
 drivers/xen/netfront/netfront.c |    6 +++---
 drivers/xen/netfront/netfront.h |    8 ++++----
 3 files changed, 11 insertions(+), 11 deletions(-)

diff -r 7ab0c1e671a2 -r d85cb3fd1011 drivers/xen/netfront/netfront.c
--- a/drivers/xen/netfront/netfront.c   Tue Oct 30 17:32:56 2007 +0000
+++ b/drivers/xen/netfront/netfront.c   Tue Oct 30 17:33:49 2007 +0000
@@ -593,12 +593,12 @@ static inline void network_maybe_wake_tx
        if (unlikely(netif_queue_stopped(dev)) &&
            netfront_tx_slot_available(np) &&
            likely(netif_running(dev)) &&
-           netfront_check_accelerator_queue_busy(dev, np))
+           netfront_check_accelerator_queue_ready(dev, np))
                netif_wake_queue(dev);
 }
 
 
-int netfront_check_queue_busy(struct net_device *dev)
+int netfront_check_queue_ready(struct net_device *dev)
 {
        struct netfront_info *np = netdev_priv(dev);
 
@@ -606,7 +606,7 @@ int netfront_check_queue_busy(struct net
                netfront_tx_slot_available(np) &&
                likely(netif_running(dev));
 }
-EXPORT_SYMBOL(netfront_check_queue_busy);
+EXPORT_SYMBOL(netfront_check_queue_ready);
 
 
 static int network_open(struct net_device *dev)
diff -r 7ab0c1e671a2 -r d85cb3fd1011 drivers/xen/netfront/netfront.h
--- a/drivers/xen/netfront/netfront.h   Tue Oct 30 17:32:56 2007 +0000
+++ b/drivers/xen/netfront/netfront.h   Tue Oct 30 17:33:49 2007 +0000
@@ -85,7 +85,7 @@ struct netfront_accel_hooks {
         * Called before re-enabling the TX queue to check the fast
         * path has slots too
         */
-       int (*check_busy)(struct net_device *dev);
+       int (*check_ready)(struct net_device *dev);
        /*
         * Get the fastpath network statistics
         */
@@ -254,7 +254,7 @@ extern void netfront_accelerator_stop(co
  * ensure the slow path has available slots.  Returns true if OK to
  * wake, false if still busy 
  */
-extern int netfront_check_queue_busy(struct net_device *net_dev);
+extern int netfront_check_queue_ready(struct net_device *net_dev);
 
 
 
@@ -266,8 +266,8 @@ extern int netfront_check_queue_busy(str
  * if still busy
  */ 
 extern 
-int netfront_check_accelerator_queue_busy(struct net_device *dev,
-                                         struct netfront_info *np);
+int netfront_check_accelerator_queue_ready(struct net_device *dev,
+                                          struct netfront_info *np);
 extern
 int netfront_accelerator_call_remove(struct netfront_info *np,
                                     struct xenbus_device *dev);

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog

<Prev in Thread] Current Thread [Next in Thread>
  • [Xen-changelog] [linux-2.6.18-xen] netfront accel: rename check_busy acceleration callback to check_ready, Xen patchbot-linux-2.6.18-xen <=
diff -r 7ab0c1e671a2 -r d85cb3fd1011 drivers/xen/netfront/accel.c
--- a/drivers/xen/netfront/accel.c      Tue Oct 30 17:32:56 2007 +0000
+++ b/drivers/xen/netfront/accel.c      Tue Oct 30 17:33:49 2007 +0000
@@ -605,8 +605,8 @@ EXPORT_SYMBOL_GPL(netfront_accelerator_s
 
 
 
-int netfront_check_accelerator_queue_busy(struct net_device *dev,
-                                         struct netfront_info *np)
+int netfront_check_accelerator_queue_ready(struct net_device *dev,
+                                          struct netfront_info *np)
 {
        struct netfront_accelerator *accelerator;
        struct netfront_accel_hooks *hooks;
@@ -616,7 +616,7 @@ int netfront_check_accelerator_queue_bus
        accelerator = np->accelerator;
 
        /*
         * Call the check busy accelerator hook. The use count for the
         * accelerator's hooks is incremented for the duration of the
         * call to prevent the accelerator being able to modify the
         * hooks in the middle (by, for example, unloading)
@@ -629,7 +629,7 @@ int netfront_check_accelerator_queue_bus
                        spin_unlock_irqrestore
                                (&accelerator->vif_states_lock, flags);
 
-                       rc = np->accel_vif_state.hooks->check_busy(dev);
+                       rc = np->accel_vif_state.hooks->check_ready(dev);
                        
                        kref_put(&np->accel_vif_state.vif_kref,
                                 vif_kref_release);
@@ -616,7 +616,7 @@ int netfront_check_accelerator_queue_bus
 
        /*
-        * Call the check busy accelerator hook. The use count for the
+        * Call the check ready accelerator hook. The use count for the
         * accelerator's hooks is incremented for the duration of the
         * call to prevent the accelerator being able to modify the